@@ -23,12 +23,12 @@ positional arguments:
                  [@subfolder][@folder]
                  Show all available connections globaly or in specified path
 Options:
-  -h, --help     show this help message and exit
-  --add          Add new node[@subfolder][@folder] or [@subfolder]@folder
-  --del, --rm    Delete node[@subfolder][@folder] or [@subfolder]@folder
-  --mod, --edit  Modify node[@subfolder][@folder]
-  --show         Show node[@subfolder][@folder]
-  --debug, -d    Display all conections steps
+  -h, --help         show this help message and exit
+  -a, --add          Add new node[@subfolder][@folder] or [@subfolder]@folder
+  -r, --del, --rm    Delete node[@subfolder][@folder] or [@subfolder]@folder
+  -e, --mod, --edit  Modify node[@subfolder][@folder]
+  -s, --show         Show node[@subfolder][@folder]
+  -d, --debug        Display all conections steps
 
 Commands:
   profile        Manage profiles
@@ -47,11 +47,12 @@ positional arguments:
   profile        Name of profile to manage
 
 options:
-  -h, --help     show this help message and exit
-  --add          Add new profile
-  --del, --rm    Delete profile
-  --mod, --edit  Modify profile
-  --show         Show profile
+  -h, --help         show this help message and exit
+  -a, --add          Add new profile
+  -r, --del, --rm    Delete profile
+  -e, --mod, --edit  Modify profile
+  -s, --show         Show profile
+
 ```
 
 ###   Examples
@@ -72,14 +73,14 @@ the automation module
 ### Standalone module
 ```
 import connpy
-router = connpy.node("unique name","ip/hostname", user="username", password="pass")
+router = connpy.node("unique name","ip/hostname", user="user", password="pass")
 router.run(["term len 0","show run"])
 print(router.output)
 hasip = router.test("show ip int brief","1.1.1.1")
 if hasip:
     print("Router has ip 1.1.1.1")
 else:
-    print("router don't has ip 1.1.1.1")
+    print("router does not have ip 1.1.1.1")
 ```
 
 ### Using manager configuration
@@ -125,7 +126,7 @@ from .connapp import connapp
 from pkg_resources import get_distribution
 
 __all__ = ["node", "nodes", "configfile", "connapp"]
-__version__ = "2.0.0"
+__version__ = "2.0.1"
 __author__ = "Federico Luzzi"
 __pdoc__ = {
     'core': False,
